@@ -1,4 +1,4 @@
-# Copyright (c) 2020  Peter Pentchev <roam@ringlet.net>
+# Copyright (c) 2020, 2021  Peter Pentchev <roam@ringlet.net>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -172,3 +172,18 @@ def test_exact_json() -> None:
         schema = tdata.SCHEMA[version]
         for value in tdata.VALUES[version]:
             do_test(json.loads(json.dumps(value)), schema)
+
+
+def test_optional() -> None:
+    """Test "?key" not present or present as a null value."""
+    schema = {"first": str, "?second": int}
+
+    trivval.validate_dict({"first": "hello"}, schema, 0)
+    trivval.validate_dict({"first": "hello", "second": None}, schema, 0)
+    trivval.validate_dict({"first": "goodbye", "second": 42}, schema, 0)
+
+    with pytest.raises(trivval.ValidationError):
+        trivval.validate_dict({"second": 42}, schema, 0)
+
+    with pytest.raises(trivval.ValidationError):
+        trivval.validate_dict({"first": "1", "second": "2"}, schema, 0)
